import * as React from "react";
import {useEffect, useRef, useState} from "react";
import ReactDOM from "react-dom";
import './index.scss';

interface PopoverContentProps {
  top: number;
  left: number;
  width: number;
  isVisible: boolean;
  content: React.ReactNode | string;
}

type Position = 'top' | 'bottom';

const PopoverContent: React.FunctionComponent<PopoverContentProps> = (props) => {
  const [contentClass, setClass] = useState('w-content w-position-top');
  const contentRef = useRef(null);
  const { isVisible, width, left, top } = props;

  useEffect(()=> {
    function positionContent(position: Position) {
      let positions = {
        top: {
          left: left + window.scrollX + width / 2 + 'px',
          top: top + window.scrollY + 'px'
        },
        bottom: {
          left: left + window.scrollX + width / 2 + 'px',
          top: top + window.scrollY + 'px'
        },
      };

      const content = contentRef.current as unknown as HTMLElement;
      content.style.left = positions[position].left;
      content.style.top = positions[position].top;
    }

    if (isVisible) {
      setClass('w-content w-position-top w-content-visible');
      positionContent('top');
    } else {
      setClass('w-content w-position-top');
    }
  }, [left, top, width, isVisible]);

  const renderContent =  (
    <div className={contentClass} ref={contentRef} >
      {props.content}
    </div>
  );

  return ReactDOM.createPortal(renderContent, document.body);
};

export default PopoverContent;
