import React, {useState, useEffect, useRef } from "react";
import Popover from './Popover';

interface TextWrapperProps {
  width: number;
  content: React.ReactNode | string;
}

const TextWrapper: React.FunctionComponent<TextWrapperProps> = (props) => {
  const {width, content} = props;
  const textRef = useRef(null);
  const [isEllipsis, setEllipsis] = useState(false);

  useEffect(()=> {
    function updateTextState() {
      if (width < computeEleWidth()) {
        setEllipsis(true)
      } else {
        setEllipsis(false)
      }
    }

    updateTextState()
  }, [content, width]);



  function computeEleWidth() {
    if (textRef && textRef.current) {
      const ele = textRef.current as unknown as HTMLElement;
      return ele.getBoundingClientRect().width
    } else {
      return 0
    }

  }

  return (
    <React.Fragment>
      <span ref={textRef} style={{marginTop: '100px'}}>
        {
          isEllipsis ?
            <Popover content={content} width={width}>{content}</Popover> :
            <span>{content}</span>
        }
      </span>
    </React.Fragment>
  );
};

TextWrapper.defaultProps = {
  width: 100
};

export default TextWrapper;
